@@ -1,5 +1,5 @@
 treecheck<-function(trees){
-if(class(trees)=="multiPhylo"){
+if(is(trees,"multiPhylo")){
 b<-c()
 u<-c()
 for (i in 1:length(trees)){
@@ -12,7 +12,7 @@ if(all(b==TRUE)) print("All trees are binary")
 if(all(u==TRUE)) print("All trees are ultrametric")
 }
 
-else if(class(trees)=="phylo") {
+else if(is(trees,"phylo")) {
 if(is.binary.phylo(trees)==TRUE) print("Tree is binary") else print("Tree is not binary")
 if(is.ultrametric(trees)==TRUE) print("Tree is ultrametric") else print("Tree is not ultrametric")
 }
